@@ -55,7 +55,7 @@ LJ.LJType.New_From_String(LJs)
 
 LOAD.mol2(os.path.join(AMBER_DATA_DIR, "atomic_ions.mol2"))
 
-print("""Reference for spce.py:
+print("""Reference for spce:
 1. Water:
   H. J. C. Berendsen, J. R. Grigera, and T. P. Straatsma
     The missing term in effective pair potentials
@@ -87,4 +87,4 @@ print("""Reference for spce.py:
     DOI: 10.1021/jp505875v  
 """)
 
-sys.modules['__main__'].__dict__["WAT"] = SPCE
\ No newline at end of file
+sys.modules['__main__'].__dict__["WAT"] = SPCE
